#[non_exhaustive]pub struct CreateSecondaryNetworkInput {
pub client_token: Option<String>,
pub dry_run: Option<bool>,
pub ipv4_cidr_block: Option<String>,
pub network_type: Option<SecondaryNetworkType>,
pub tag_specifications: Option<Vec<TagSpecification>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.
dry_run: Option<bool>Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
ipv4_cidr_block: Option<String>The IPv4 CIDR block for the secondary network. The CIDR block size must be between /12 and /28.
network_type: Option<SecondaryNetworkType>The type of secondary network.
tag_specifications: Option<Vec<TagSpecification>>The tags to assign to the secondary network.
Implementations
Sourceimpl CreateSecondaryNetworkInput
impl CreateSecondaryNetworkInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.
Sourcepub fn dry_run(&self) -> Option<bool>
pub fn dry_run(&self) -> Option<bool>
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
Sourcepub fn ipv4_cidr_block(&self) -> Option<&str>
pub fn ipv4_cidr_block(&self) -> Option<&str>
The IPv4 CIDR block for the secondary network. The CIDR block size must be between /12 and /28.
Sourcepub fn network_type(&self) -> Option<&SecondaryNetworkType>
pub fn network_type(&self) -> Option<&SecondaryNetworkType>
The type of secondary network.
Sourcepub fn tag_specifications(&self) -> &[TagSpecification]
pub fn tag_specifications(&self) -> &[TagSpecification]
The tags to assign to the secondary network.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tag_specifications.is_none().
Sourceimpl CreateSecondaryNetworkInput
impl CreateSecondaryNetworkInput
Sourcepub fn builder() -> CreateSecondaryNetworkInputBuilder
pub fn builder() -> CreateSecondaryNetworkInputBuilder
Creates a new builder-style object to manufacture CreateSecondaryNetworkInput.