#[non_exhaustive]pub struct CreateSecondaryNetworkOutput {
pub secondary_network: Option<SecondaryNetwork>,
pub client_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.secondary_network: Option<SecondaryNetwork>Information about the secondary network.
client_token: Option<String>Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.
Implementations
Sourceimpl CreateSecondaryNetworkOutput
impl CreateSecondaryNetworkOutput
Sourcepub fn secondary_network(&self) -> Option<&SecondaryNetwork>
pub fn secondary_network(&self) -> Option<&SecondaryNetwork>
Information about the secondary network.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.
Sourceimpl CreateSecondaryNetworkOutput
impl CreateSecondaryNetworkOutput
Sourcepub fn builder() -> CreateSecondaryNetworkOutputBuilder
pub fn builder() -> CreateSecondaryNetworkOutputBuilder
Creates a new builder-style object to manufacture CreateSecondaryNetworkOutput.