#[non_exhaustive]pub struct DefaultConnectionTrackingConfigurationBuilder { /* private fields */ }Expand description
A builder for DefaultConnectionTrackingConfiguration.
Implementations
Sourceimpl DefaultConnectionTrackingConfigurationBuilder
impl DefaultConnectionTrackingConfigurationBuilder
Sourcepub fn default_tcp_established_timeout(self, input: i32) -> Self
pub fn default_tcp_established_timeout(self, input: i32) -> Self
Default timeout (in seconds) for idle TCP connections in an established state.
Sourcepub fn set_default_tcp_established_timeout(self, input: Option<i32>) -> Self
pub fn set_default_tcp_established_timeout(self, input: Option<i32>) -> Self
Default timeout (in seconds) for idle TCP connections in an established state.
Sourcepub fn get_default_tcp_established_timeout(&self) -> &Option<i32>
pub fn get_default_tcp_established_timeout(&self) -> &Option<i32>
Default timeout (in seconds) for idle TCP connections in an established state.
Sourcepub fn default_udp_timeout(self, input: i32) -> Self
pub fn default_udp_timeout(self, input: i32) -> Self
Default timeout (in seconds) for idle UDP flows that have seen traffic only in a single direction or a single request-response transaction.
Sourcepub fn set_default_udp_timeout(self, input: Option<i32>) -> Self
pub fn set_default_udp_timeout(self, input: Option<i32>) -> Self
Default timeout (in seconds) for idle UDP flows that have seen traffic only in a single direction or a single request-response transaction.
Sourcepub fn get_default_udp_timeout(&self) -> &Option<i32>
pub fn get_default_udp_timeout(&self) -> &Option<i32>
Default timeout (in seconds) for idle UDP flows that have seen traffic only in a single direction or a single request-response transaction.
Sourcepub fn default_udp_stream_timeout(self, input: i32) -> Self
pub fn default_udp_stream_timeout(self, input: i32) -> Self
Default timeout (in seconds) for idle UDP flows classified as streams which have seen more than one request-response transaction.
Sourcepub fn set_default_udp_stream_timeout(self, input: Option<i32>) -> Self
pub fn set_default_udp_stream_timeout(self, input: Option<i32>) -> Self
Default timeout (in seconds) for idle UDP flows classified as streams which have seen more than one request-response transaction.
Sourcepub fn get_default_udp_stream_timeout(&self) -> &Option<i32>
pub fn get_default_udp_stream_timeout(&self) -> &Option<i32>
Default timeout (in seconds) for idle UDP flows classified as streams which have seen more than one request-response transaction.
Sourcepub fn build(self) -> DefaultConnectionTrackingConfiguration
pub fn build(self) -> DefaultConnectionTrackingConfiguration
Consumes the builder and constructs a DefaultConnectionTrackingConfiguration.