#[non_exhaustive]pub struct InstanceSecondaryInterfaceAttachmentBuilder { /* private fields */ }Expand description
A builder for InstanceSecondaryInterfaceAttachment.
Implementations
Sourceimpl InstanceSecondaryInterfaceAttachmentBuilder
impl InstanceSecondaryInterfaceAttachmentBuilder
Sourcepub fn attach_time(self, input: DateTime) -> Self
pub fn attach_time(self, input: DateTime) -> Self
The timestamp when the attachment was created.
Sourcepub fn set_attach_time(self, input: Option<DateTime>) -> Self
pub fn set_attach_time(self, input: Option<DateTime>) -> Self
The timestamp when the attachment was created.
Sourcepub fn get_attach_time(&self) -> &Option<DateTime>
pub fn get_attach_time(&self) -> &Option<DateTime>
The timestamp when the attachment was created.
Sourcepub fn attachment_id(self, input: impl Into<String>) -> Self
pub fn attachment_id(self, input: impl Into<String>) -> Self
The ID of the attachment.
Sourcepub fn set_attachment_id(self, input: Option<String>) -> Self
pub fn set_attachment_id(self, input: Option<String>) -> Self
The ID of the attachment.
Sourcepub fn get_attachment_id(&self) -> &Option<String>
pub fn get_attachment_id(&self) -> &Option<String>
The ID of the attachment.
Sourcepub fn delete_on_termination(self, input: bool) -> Self
pub fn delete_on_termination(self, input: bool) -> Self
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
Sourcepub fn set_delete_on_termination(self, input: Option<bool>) -> Self
pub fn set_delete_on_termination(self, input: Option<bool>) -> Self
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
Sourcepub fn get_delete_on_termination(&self) -> &Option<bool>
pub fn get_delete_on_termination(&self) -> &Option<bool>
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
Sourcepub fn device_index(self, input: i32) -> Self
pub fn device_index(self, input: i32) -> Self
The device index of the secondary interface.
Sourcepub fn set_device_index(self, input: Option<i32>) -> Self
pub fn set_device_index(self, input: Option<i32>) -> Self
The device index of the secondary interface.
Sourcepub fn get_device_index(&self) -> &Option<i32>
pub fn get_device_index(&self) -> &Option<i32>
The device index of the secondary interface.
Sourcepub fn status(self, input: AttachmentStatus) -> Self
pub fn status(self, input: AttachmentStatus) -> Self
The attachment state.
Sourcepub fn set_status(self, input: Option<AttachmentStatus>) -> Self
pub fn set_status(self, input: Option<AttachmentStatus>) -> Self
The attachment state.
Sourcepub fn get_status(&self) -> &Option<AttachmentStatus>
pub fn get_status(&self) -> &Option<AttachmentStatus>
The attachment state.
Sourcepub fn network_card_index(self, input: i32) -> Self
pub fn network_card_index(self, input: i32) -> Self
The index of the network card.
Sourcepub fn set_network_card_index(self, input: Option<i32>) -> Self
pub fn set_network_card_index(self, input: Option<i32>) -> Self
The index of the network card.
Sourcepub fn get_network_card_index(&self) -> &Option<i32>
pub fn get_network_card_index(&self) -> &Option<i32>
The index of the network card.
Sourcepub fn build(self) -> InstanceSecondaryInterfaceAttachment
pub fn build(self) -> InstanceSecondaryInterfaceAttachment
Consumes the builder and constructs a InstanceSecondaryInterfaceAttachment.