#[non_exhaustive]pub struct InstanceSecondaryInterfaceSpecificationRequestBuilder { /* private fields */ }Expand description
A builder for InstanceSecondaryInterfaceSpecificationRequest.
Implementations
Sourceimpl InstanceSecondaryInterfaceSpecificationRequestBuilder
impl InstanceSecondaryInterfaceSpecificationRequestBuilder
Sourcepub fn delete_on_termination(self, input: bool) -> Self
pub fn delete_on_termination(self, input: bool) -> Self
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
Sourcepub fn set_delete_on_termination(self, input: Option<bool>) -> Self
pub fn set_delete_on_termination(self, input: Option<bool>) -> Self
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
Sourcepub fn get_delete_on_termination(&self) -> &Option<bool>
pub fn get_delete_on_termination(&self) -> &Option<bool>
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
Sourcepub fn device_index(self, input: i32) -> Self
pub fn device_index(self, input: i32) -> Self
The device index for the secondary interface attachment.
Sourcepub fn set_device_index(self, input: Option<i32>) -> Self
pub fn set_device_index(self, input: Option<i32>) -> Self
The device index for the secondary interface attachment.
Sourcepub fn get_device_index(&self) -> &Option<i32>
pub fn get_device_index(&self) -> &Option<i32>
The device index for the secondary interface attachment.
Sourcepub fn private_ip_addresses(
self,
input: InstanceSecondaryInterfacePrivateIpAddressRequest,
) -> Self
pub fn private_ip_addresses( self, input: InstanceSecondaryInterfacePrivateIpAddressRequest, ) -> Self
Appends an item to private_ip_addresses.
To override the contents of this collection use set_private_ip_addresses.
The private IPv4 addresses to assign to the secondary interface.
Sourcepub fn set_private_ip_addresses(
self,
input: Option<Vec<InstanceSecondaryInterfacePrivateIpAddressRequest>>,
) -> Self
pub fn set_private_ip_addresses( self, input: Option<Vec<InstanceSecondaryInterfacePrivateIpAddressRequest>>, ) -> Self
The private IPv4 addresses to assign to the secondary interface.
Sourcepub fn get_private_ip_addresses(
&self,
) -> &Option<Vec<InstanceSecondaryInterfacePrivateIpAddressRequest>>
pub fn get_private_ip_addresses( &self, ) -> &Option<Vec<InstanceSecondaryInterfacePrivateIpAddressRequest>>
The private IPv4 addresses to assign to the secondary interface.
Sourcepub fn private_ip_address_count(self, input: i32) -> Self
pub fn private_ip_address_count(self, input: i32) -> Self
The number of private IPv4 addresses to assign to the secondary interface.
Sourcepub fn set_private_ip_address_count(self, input: Option<i32>) -> Self
pub fn set_private_ip_address_count(self, input: Option<i32>) -> Self
The number of private IPv4 addresses to assign to the secondary interface.
Sourcepub fn get_private_ip_address_count(&self) -> &Option<i32>
pub fn get_private_ip_address_count(&self) -> &Option<i32>
The number of private IPv4 addresses to assign to the secondary interface.
Sourcepub fn secondary_subnet_id(self, input: impl Into<String>) -> Self
pub fn secondary_subnet_id(self, input: impl Into<String>) -> Self
The ID of the secondary subnet.
Sourcepub fn set_secondary_subnet_id(self, input: Option<String>) -> Self
pub fn set_secondary_subnet_id(self, input: Option<String>) -> Self
The ID of the secondary subnet.
Sourcepub fn get_secondary_subnet_id(&self) -> &Option<String>
pub fn get_secondary_subnet_id(&self) -> &Option<String>
The ID of the secondary subnet.
Sourcepub fn interface_type(self, input: SecondaryInterfaceType) -> Self
pub fn interface_type(self, input: SecondaryInterfaceType) -> Self
The type of secondary interface.
Sourcepub fn set_interface_type(self, input: Option<SecondaryInterfaceType>) -> Self
pub fn set_interface_type(self, input: Option<SecondaryInterfaceType>) -> Self
The type of secondary interface.
Sourcepub fn get_interface_type(&self) -> &Option<SecondaryInterfaceType>
pub fn get_interface_type(&self) -> &Option<SecondaryInterfaceType>
The type of secondary interface.
Sourcepub fn network_card_index(self, input: i32) -> Self
pub fn network_card_index(self, input: i32) -> Self
The index of the network card. The network card must support secondary interfaces.
Sourcepub fn set_network_card_index(self, input: Option<i32>) -> Self
pub fn set_network_card_index(self, input: Option<i32>) -> Self
The index of the network card. The network card must support secondary interfaces.
Sourcepub fn get_network_card_index(&self) -> &Option<i32>
pub fn get_network_card_index(&self) -> &Option<i32>
The index of the network card. The network card must support secondary interfaces.
Sourcepub fn build(self) -> InstanceSecondaryInterfaceSpecificationRequest
pub fn build(self) -> InstanceSecondaryInterfaceSpecificationRequest
Consumes the builder and constructs a InstanceSecondaryInterfaceSpecificationRequest.