#[non_exhaustive]pub struct ReservedCapacityOptionsBuilder { /* private fields */ }Expand description
A builder for ReservedCapacityOptions.
Implementations
Sourceimpl ReservedCapacityOptionsBuilder
impl ReservedCapacityOptionsBuilder
Sourcepub fn reservation_types(self, input: FleetReservationType) -> Self
pub fn reservation_types(self, input: FleetReservationType) -> Self
Appends an item to reservation_types.
To override the contents of this collection use set_reservation_types.
The types of Capacity Reservations used for fulfilling the EC2 Fleet request.
Sourcepub fn set_reservation_types(
self,
input: Option<Vec<FleetReservationType>>,
) -> Self
pub fn set_reservation_types( self, input: Option<Vec<FleetReservationType>>, ) -> Self
The types of Capacity Reservations used for fulfilling the EC2 Fleet request.
Sourcepub fn get_reservation_types(&self) -> &Option<Vec<FleetReservationType>>
pub fn get_reservation_types(&self) -> &Option<Vec<FleetReservationType>>
The types of Capacity Reservations used for fulfilling the EC2 Fleet request.
Sourcepub fn build(self) -> ReservedCapacityOptions
pub fn build(self) -> ReservedCapacityOptions
Consumes the builder and constructs a ReservedCapacityOptions.