#[non_exhaustive]pub struct ReservedCapacityOptionsRequestBuilder { /* private fields */ }Expand description
A builder for ReservedCapacityOptionsRequest.
Implementations
Sourceimpl ReservedCapacityOptionsRequestBuilder
impl ReservedCapacityOptionsRequestBuilder
Sourcepub fn reservation_types(self, input: FleetReservationType) -> Self
pub fn reservation_types(self, input: FleetReservationType) -> Self
Appends an item to reservation_types.
To override the contents of this collection use set_reservation_types.
The types of Capacity Reservations to use for fulfilling the EC2 Fleet request.
Sourcepub fn set_reservation_types(
self,
input: Option<Vec<FleetReservationType>>,
) -> Self
pub fn set_reservation_types( self, input: Option<Vec<FleetReservationType>>, ) -> Self
The types of Capacity Reservations to use for fulfilling the EC2 Fleet request.
Sourcepub fn get_reservation_types(&self) -> &Option<Vec<FleetReservationType>>
pub fn get_reservation_types(&self) -> &Option<Vec<FleetReservationType>>
The types of Capacity Reservations to use for fulfilling the EC2 Fleet request.
Sourcepub fn build(self) -> ReservedCapacityOptionsRequest
pub fn build(self) -> ReservedCapacityOptionsRequest
Consumes the builder and constructs a ReservedCapacityOptionsRequest.