#[non_exhaustive]pub enum DefaultHttpTokensEnforcedState {
Disabled,
Enabled,
NoPreference,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against DefaultHttpTokensEnforcedState, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let defaulthttptokensenforcedstate = unimplemented!();
match defaulthttptokensenforcedstate {
DefaultHttpTokensEnforcedState::Disabled => { /* ... */ },
DefaultHttpTokensEnforcedState::Enabled => { /* ... */ },
DefaultHttpTokensEnforcedState::NoPreference => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when defaulthttptokensenforcedstate represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant DefaultHttpTokensEnforcedState::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
DefaultHttpTokensEnforcedState::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant DefaultHttpTokensEnforcedState::NewFeature is defined.
Specifically, when defaulthttptokensenforcedstate represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on DefaultHttpTokensEnforcedState::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Disabled
Enabled
NoPreference
Unknown(UnknownVariantValue)
Unknown. See the docs on this enum for the correct way to handle unknown variants.Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl DefaultHttpTokensEnforcedState
impl DefaultHttpTokensEnforcedState
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.