#[non_exhaustive]pub struct DefaultConnectionTrackingConfiguration {
pub default_tcp_established_timeout: Option<i32>,
pub default_udp_timeout: Option<i32>,
pub default_udp_stream_timeout: Option<i32>,
}Expand description
Indicates default conntrack information for the instance type. For more information, see Connection tracking timeouts in the Amazon EC2 User Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.default_tcp_established_timeout: Option<i32>Default timeout (in seconds) for idle TCP connections in an established state.
default_udp_timeout: Option<i32>Default timeout (in seconds) for idle UDP flows that have seen traffic only in a single direction or a single request-response transaction.
default_udp_stream_timeout: Option<i32>Default timeout (in seconds) for idle UDP flows classified as streams which have seen more than one request-response transaction.
Implementations
Sourceimpl DefaultConnectionTrackingConfiguration
impl DefaultConnectionTrackingConfiguration
Sourcepub fn default_tcp_established_timeout(&self) -> Option<i32>
pub fn default_tcp_established_timeout(&self) -> Option<i32>
Default timeout (in seconds) for idle TCP connections in an established state.
Sourcepub fn default_udp_timeout(&self) -> Option<i32>
pub fn default_udp_timeout(&self) -> Option<i32>
Default timeout (in seconds) for idle UDP flows that have seen traffic only in a single direction or a single request-response transaction.
Sourcepub fn default_udp_stream_timeout(&self) -> Option<i32>
pub fn default_udp_stream_timeout(&self) -> Option<i32>
Default timeout (in seconds) for idle UDP flows classified as streams which have seen more than one request-response transaction.
Sourceimpl DefaultConnectionTrackingConfiguration
impl DefaultConnectionTrackingConfiguration
Sourcepub fn builder() -> DefaultConnectionTrackingConfigurationBuilder
pub fn builder() -> DefaultConnectionTrackingConfigurationBuilder
Creates a new builder-style object to manufacture DefaultConnectionTrackingConfiguration.