#[non_exhaustive]pub struct InstanceSecondaryInterfaceAttachment {
pub attach_time: Option<DateTime>,
pub attachment_id: Option<String>,
pub delete_on_termination: Option<bool>,
pub device_index: Option<i32>,
pub status: Option<AttachmentStatus>,
pub network_card_index: Option<i32>,
}Expand description
Describes the attachment of a secondary interface to an instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.attach_time: Option<DateTime>The timestamp when the attachment was created.
attachment_id: Option<String>The ID of the attachment.
delete_on_termination: Option<bool>Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
device_index: Option<i32>The device index of the secondary interface.
status: Option<AttachmentStatus>The attachment state.
network_card_index: Option<i32>The index of the network card.
Implementations
Sourceimpl InstanceSecondaryInterfaceAttachment
impl InstanceSecondaryInterfaceAttachment
Sourcepub fn attach_time(&self) -> Option<&DateTime>
pub fn attach_time(&self) -> Option<&DateTime>
The timestamp when the attachment was created.
Sourcepub fn attachment_id(&self) -> Option<&str>
pub fn attachment_id(&self) -> Option<&str>
The ID of the attachment.
Sourcepub fn delete_on_termination(&self) -> Option<bool>
pub fn delete_on_termination(&self) -> Option<bool>
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
Sourcepub fn device_index(&self) -> Option<i32>
pub fn device_index(&self) -> Option<i32>
The device index of the secondary interface.
Sourcepub fn status(&self) -> Option<&AttachmentStatus>
pub fn status(&self) -> Option<&AttachmentStatus>
The attachment state.
Sourcepub fn network_card_index(&self) -> Option<i32>
pub fn network_card_index(&self) -> Option<i32>
The index of the network card.
Sourceimpl InstanceSecondaryInterfaceAttachment
impl InstanceSecondaryInterfaceAttachment
Sourcepub fn builder() -> InstanceSecondaryInterfaceAttachmentBuilder
pub fn builder() -> InstanceSecondaryInterfaceAttachmentBuilder
Creates a new builder-style object to manufacture InstanceSecondaryInterfaceAttachment.