#[non_exhaustive]pub struct InstanceSecondaryInterfaceSpecificationRequest {
pub delete_on_termination: Option<bool>,
pub device_index: Option<i32>,
pub private_ip_addresses: Option<Vec<InstanceSecondaryInterfacePrivateIpAddressRequest>>,
pub private_ip_address_count: Option<i32>,
pub secondary_subnet_id: Option<String>,
pub interface_type: Option<SecondaryInterfaceType>,
pub network_card_index: Option<i32>,
}Expand description
Describes a secondary interface specification for launching an instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delete_on_termination: Option<bool>Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
device_index: Option<i32>The device index for the secondary interface attachment.
private_ip_addresses: Option<Vec<InstanceSecondaryInterfacePrivateIpAddressRequest>>The private IPv4 addresses to assign to the secondary interface.
private_ip_address_count: Option<i32>The number of private IPv4 addresses to assign to the secondary interface.
secondary_subnet_id: Option<String>The ID of the secondary subnet.
interface_type: Option<SecondaryInterfaceType>The type of secondary interface.
network_card_index: Option<i32>The index of the network card. The network card must support secondary interfaces.
Implementations
Sourceimpl InstanceSecondaryInterfaceSpecificationRequest
impl InstanceSecondaryInterfaceSpecificationRequest
Sourcepub fn delete_on_termination(&self) -> Option<bool>
pub fn delete_on_termination(&self) -> Option<bool>
Indicates whether the secondary interface is deleted when the instance is terminated.
The only supported value for this field is true.
Sourcepub fn device_index(&self) -> Option<i32>
pub fn device_index(&self) -> Option<i32>
The device index for the secondary interface attachment.
Sourcepub fn private_ip_addresses(
&self,
) -> &[InstanceSecondaryInterfacePrivateIpAddressRequest]
pub fn private_ip_addresses( &self, ) -> &[InstanceSecondaryInterfacePrivateIpAddressRequest]
The private IPv4 addresses to assign to the secondary interface.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .private_ip_addresses.is_none().
Sourcepub fn private_ip_address_count(&self) -> Option<i32>
pub fn private_ip_address_count(&self) -> Option<i32>
The number of private IPv4 addresses to assign to the secondary interface.
Sourcepub fn secondary_subnet_id(&self) -> Option<&str>
pub fn secondary_subnet_id(&self) -> Option<&str>
The ID of the secondary subnet.
Sourcepub fn interface_type(&self) -> Option<&SecondaryInterfaceType>
pub fn interface_type(&self) -> Option<&SecondaryInterfaceType>
The type of secondary interface.
Sourcepub fn network_card_index(&self) -> Option<i32>
pub fn network_card_index(&self) -> Option<i32>
The index of the network card. The network card must support secondary interfaces.
Sourceimpl InstanceSecondaryInterfaceSpecificationRequest
impl InstanceSecondaryInterfaceSpecificationRequest
Sourcepub fn builder() -> InstanceSecondaryInterfaceSpecificationRequestBuilder
pub fn builder() -> InstanceSecondaryInterfaceSpecificationRequestBuilder
Creates a new builder-style object to manufacture InstanceSecondaryInterfaceSpecificationRequest.