#[non_exhaustive]pub struct SecondaryNetwork {
pub secondary_network_id: Option<String>,
pub secondary_network_arn: Option<String>,
pub owner_id: Option<String>,
pub type: Option<SecondaryNetworkType>,
pub state: Option<SecondaryNetworkState>,
pub state_reason: Option<String>,
pub ipv4_cidr_block_associations: Option<Vec<SecondaryNetworkIpv4CidrBlockAssociation>>,
pub tags: Option<Vec<Tag>>,
}Expand description
Describes a secondary network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.secondary_network_id: Option<String>The ID of the secondary network.
secondary_network_arn: Option<String>The Amazon Resource Name (ARN) of the secondary network.
owner_id: Option<String>The ID of the Amazon Web Services account that owns the secondary network.
type: Option<SecondaryNetworkType>The type of the secondary network.
state: Option<SecondaryNetworkState>The state of the secondary network.
state_reason: Option<String>The reason for the current state of the secondary network.
ipv4_cidr_block_associations: Option<Vec<SecondaryNetworkIpv4CidrBlockAssociation>>Information about the IPv4 CIDR blocks associated with the secondary network.
The tags assigned to the secondary network.
Implementations
Sourceimpl SecondaryNetwork
impl SecondaryNetwork
Sourcepub fn secondary_network_id(&self) -> Option<&str>
pub fn secondary_network_id(&self) -> Option<&str>
The ID of the secondary network.
Sourcepub fn secondary_network_arn(&self) -> Option<&str>
pub fn secondary_network_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the secondary network.
Sourcepub fn owner_id(&self) -> Option<&str>
pub fn owner_id(&self) -> Option<&str>
The ID of the Amazon Web Services account that owns the secondary network.
Sourcepub fn type(&self) -> Option<&SecondaryNetworkType>
pub fn type(&self) -> Option<&SecondaryNetworkType>
The type of the secondary network.
Sourcepub fn state(&self) -> Option<&SecondaryNetworkState>
pub fn state(&self) -> Option<&SecondaryNetworkState>
The state of the secondary network.
Sourcepub fn state_reason(&self) -> Option<&str>
pub fn state_reason(&self) -> Option<&str>
The reason for the current state of the secondary network.
Sourcepub fn ipv4_cidr_block_associations(
&self,
) -> &[SecondaryNetworkIpv4CidrBlockAssociation]
pub fn ipv4_cidr_block_associations( &self, ) -> &[SecondaryNetworkIpv4CidrBlockAssociation]
Information about the IPv4 CIDR blocks associated with the secondary network.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .ipv4_cidr_block_associations.is_none().
The tags assigned to the secondary network.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourceimpl SecondaryNetwork
impl SecondaryNetwork
Sourcepub fn builder() -> SecondaryNetworkBuilder
pub fn builder() -> SecondaryNetworkBuilder
Creates a new builder-style object to manufacture SecondaryNetwork.